herosdevices.core.bus.onewire - Heros Devices 0.6.1 documentation

Skip to content
Back to top
View this page

# herosdevices.core.bus.onewire

This module provides a class for managing OneWire connections.

## Module Contents

class herosdevices.core.bus.onewire.OneWire(device_id: str, sysfs_path: str = '/sys/bus/w1/')

  A read-only Onewire driver that relies on the Linux kernel w1 driver.

  Linux exposes onewire devices in sysfs. This driver can read the sysfs files as they are specified in the :param sensors: list.

  sysfs_path